@@ -13,6 +13,8 @@ if TYPE_CHECKING:
     from .analysis import AnalysisSpec
     from .config import ConfigCollection
     from .experiment import ExperimentConfiguration
+    from .definition import DefinitionSpecSub
+    from .project import ProjectConfiguration
 
 from .data_source import DataSource, DataSourceReference
 from .parameter import ParameterDefinition
@@ -70,6 +72,8 @@ class Metric:
     description: Optional[str] = None
     bigger_is_better: bool = True
     analysis_bases: List[AnalysisBasis] = [AnalysisBasis.ENROLLMENTS]
+    type: str = "scalar"
+    category: Optional[str] = None
 
 
 @attr.s(auto_attribs=True)
@@ -79,15 +83,15 @@ class MetricReference:
     def resolve(
         self,
         spec: "AnalysisSpec",
-        experiment: "ExperimentConfiguration",
+        conf: Union["ExperimentConfiguration", "ProjectConfiguration"],
         configs: "ConfigCollection",
     ) -> List[Summary]:
         if self.name in spec.metrics.definitions:
-            return spec.metrics.definitions[self.name].resolve(spec, experiment, configs)
+            return spec.metrics.definitions[self.name].resolve(spec, conf, configs)
 
-        metric_definition = configs.get_metric_definition(self.name, experiment.experiment.app_name)
+        metric_definition = configs.get_metric_definition(self.name, conf.app_name)
         if metric_definition:
-            return metric_definition.resolve(spec, experiment, configs=configs)
+            return metric_definition.resolve(spec, conf, configs=configs)
 
         raise DefinitionNotFound(f"Could not locate metric {self.name}")
 
@@ -113,6 +117,8 @@ class MetricDefinition:
     description: Optional[str] = None
     bigger_is_better: bool = True
     analysis_bases: Optional[List[AnalysisBasis]] = None
+    type: Optional[str] = None
+    category: Optional[str] = None
 
     @staticmethod
     def generate_select_expression(
@@ -152,8 +158,8 @@ class MetricDefinition:
 
     def resolve(
         self,
-        spec: "AnalysisSpec",
-        experiment: "ExperimentConfiguration",
+        spec: "DefinitionSpecSub",
+        conf: Union["ExperimentConfiguration", "ProjectConfiguration"],
         configs: "ConfigCollection",
     ) -> List[Summary]:
         metric_summary = None
@@ -161,9 +167,7 @@ class MetricDefinition:
 
         if self.select_expression is None or self.data_source is None:
             # checks if a metric from mozanalysis was referenced
-            metric_definition = configs.get_metric_definition(
-                self.name, experiment.experiment.app_name
-            )
+            metric_definition = configs.get_metric_definition(self.name, conf.app_name)
 
             if metric_definition is None:
                 raise DefinitionNotFound(
@@ -171,7 +175,7 @@ class MetricDefinition:
                 )
 
             metric_definition.analysis_bases = self.analysis_bases or [AnalysisBasis.ENROLLMENTS]
-            metric_summary = metric_definition.resolve(spec, experiment, configs)
+            metric_summary = metric_definition.resolve(spec, conf, configs)
         else:
             select_expression = self.generate_select_expression(
                 spec.parameters.definitions,
@@ -181,7 +185,7 @@ class MetricDefinition:
 
             metric = Metric(
                 name=self.name,
-                data_source=self.data_source.resolve(spec, experiment, configs),
+                data_source=self.data_source.resolve(spec, conf, configs),
                 select_expression=select_expression,
                 friendly_name=dedent(self.friendly_name)
                 if self.friendly_name
@@ -189,6 +193,8 @@ class MetricDefinition:
                 description=dedent(self.description) if self.description else self.description,
                 bigger_is_better=self.bigger_is_better,
                 analysis_bases=self.analysis_bases or [AnalysisBasis.ENROLLMENTS],
+                type=self.type or "scalar",
+                category=self.category,
             )
 
         metrics_with_treatments = []
@@ -243,6 +249,11 @@ class MetricDefinition:
 
         return metrics_with_treatments
 
+    def merge(self, other: "MetricDefinition"):
+        """Merge with another metric definition."""
+        for key in attr.fields_dict(type(self)):
+            setattr(self, key, getattr(other, key) or getattr(self, key))
+
 
 MetricsConfigurationType = Dict[AnalysisPeriod, List[Summary]]
 
@@ -283,7 +294,7 @@ class MetricsSpec:
     def resolve(
         self,
         spec: "AnalysisSpec",
-        experiment: "ExperimentConfiguration",
+        conf: Union["ExperimentConfiguration", "ProjectConfiguration"],
         configs: "ConfigCollection",
     ) -> MetricsConfigurationType:
         result = {}
@@ -291,7 +302,7 @@ class MetricsSpec:
             summaries = [
                 summary
                 for ref in getattr(self, period.table_suffix)
-                for summary in ref.resolve(spec, experiment, configs)
+                for summary in ref.resolve(spec, conf, configs)
             ]
             unique_summaries = []
             seen_summaries = set()
@@ -317,7 +328,15 @@ class MetricsSpec:
         self.weekly += other.weekly
         self.days28 += other.days28
         self.overall += other.overall
-        self.definitions.update(other.definitions)
+
+        seen = []
+        for key, _ in self.definitions.items():
+            if key in other.definitions:
+                self.definitions[key].merge(other.definitions[key])
+            seen.append(key)
+        for key, definition in other.definitions.items():
+            if key not in seen:
+                self.definitions[key] = definition
 
 
 converter.register_structure_hook(MetricsSpec, lambda obj, _type: MetricsSpec.from_dict(obj))
